/*
 * Copyright (C) 2013 by egnite GmbH
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the copyright holders nor the names of
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * For additional information see http://www.ethernut.de/
 */

/*
 * A simple Nut/OS program to demonstrate how to set the real-time clock.
 * using the I2C bus driver.
 */

/* Include some Nut/OS header files. */
#include <dev/debug.h>
#include <dev/i2cbus.h>
#include <dev/i2cbus_at91.h>
#include <dev/i2c_pcf85xx.h>
#include <sys/timer.h>
#include <pro/rfctime.h>

/* Include some standard header files. */
#include <stdlib.h>
#include <string.h>
#include <stdio.h>

/*
 * Initialize required devices.
 */
static void InitDevices(void)
{
    /* Initialize debug port for stdout. */
    NutRegisterDevice(&devDebug, 0, 0);
    freopen("dbgu", "w", stdout);

    if (NutRegisterI2cSlave((NUTI2C_SLAVE *) rtcI2cPcf85xx.dcb, &i2cBus0At91) == 0) {
        NutRegisterRtc(&rtcI2cPcf85xx);
    }
}


/*
 * The program starts here.
 */
int main(void)
{
    time_t now;

    /* Initialize all devices. */
    InitDevices();

    /* Print banner on console. */
    puts("\n=*= Real-time clock reader =*=");

    /* Never return from main(). */
    for (;;) {
        now = time(NULL);
        printf("\r%s   ", Rfc1123TimeString(gmtime(&now)));
        NutSleep(500);
    }
}
